function [X,Fx]=hyperpmf_marg(theta,varargin)

d=size(theta,2);

%---------------------------------------------------------------------------
% If there is a scalar argument, then the user wants to generate an n-sized
% sample of the pmf
%---------------------------------------------------------------------------
if numel(varargin{1})==1
    n=varargin{1};

    % Generate nominal sample:
    % - cluster center: S
    % - probability depends on Hamming distance from S: p(x) is proportional to
    %   h ^ -|x-S|
    % - make sure there are no vertices within 1-Hamming radius of the origin 
    
    X=zeros(n,d);
    Theta=repmat(theta,n,1);
   
    fail=1:n; len=length(fail);
    while len>0
       X(fail,:)=rand(len,d);
       X(fail,:)=X(fail,:)<Theta(fail,:);
       fail=find(sum(X,2)<2);
       len=length(fail);
    end

%--------------------------------------------------------------------------
% Otherwise, then the user just wants to evaluate the pmf at X
%--------------------------------------------------------------------------
else
    X=varargin{1};
    n=size(X,1);
    Theta=repmat(theta,n,1);
end

%--------------------------------------------------------------------------
% In any case, always return the log pmf values at X
%--------------------------------------------------------------------------

%Fx=sum(X.*(log(Theta))+(1-X).*(log(1-Theta)),2);

H=[theta; 1-theta];
Hx=X.*repmat(H(1,:),n,1) + (1-X).*repmat(H(2,:),n,1);

logHx=log(Hx+realmin);
Fx=sum(logHx,2);

invalid=find(sum(X,2)<2);
Fx(invalid,:)=-realmax;